@@ -26,11 +26,16 @@
  */
 
 #define ICON_SIZE 24.0
+#define GNOME_SEARCH_TOOL_DEFAULT_ICON_SIZE 48
+#define GNOME_SEARCH_TOOL_STOCK "panel-searchtool"
+#define LEFT_LABEL_SPACING "   "
 
 #ifdef HAVE_CONFIG_H
 #  include <config.h>
 #endif
 
+#include <gnome.h>
+
 #include "gsearchtool.h"
 #include "gsearchtool-support.h"
 #include "gsearchtool-callbacks.h"
@@ -39,15 +44,13 @@
 #include <unistd.h>
 #include <signal.h>
 #include <fnmatch.h>
-#include <sys/wait.h>
-#include <gdk/gdkkeysyms.h>
-#include <libgnomeui/gnome-window-icon.h>
-#include <libgnomevfs/gnome-vfs-mime.h>
-#include <libgnomevfs/gnome-vfs-mime-handlers.h>
+#include <libbonobo.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
 #include <libgnomevfs/gnome-vfs-ops.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
+static GtkIconSize gsearchtool_icon_size = 0;
+
 typedef struct _FindOptionTemplate FindOptionTemplate;
 struct _FindOptionTemplate {
 	SearchConstraintType type;
@@ -515,9 +518,11 @@ set_constraint_selected_state (gint 		constraint_id,
 		if (templates[index].is_selected == FALSE) {
 			gtk_option_menu_set_history (GTK_OPTION_MENU(interface.constraint_menu), index);
 			interface.selected_constraint = (long)index;
-			break;
+			gtk_widget_set_sensitive (interface.add_button, TRUE);
+			return;
 		}
 	}
+	gtk_widget_set_sensitive (interface.add_button, FALSE);
 }
 
 static void
@@ -714,7 +719,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 
 		do {
 			gint  status;
-			gchar *locale = NULL;
+			gchar *utf8 = NULL;
 			gchar *filename = NULL;
 			
 			if (search_data->running != RUNNING) {
@@ -746,14 +751,14 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 				continue;
 			}
 			
-			locale = g_locale_to_utf8 (string->str, -1, NULL, NULL, NULL);
-			if (locale == NULL) {
+			utf8 = g_locale_to_utf8 (string->str, -1, NULL, NULL, NULL);
+			if (utf8 == NULL) {
 				continue;
 			}
 			
 			if (strncmp (string->str, search_data->look_in_folder, strlen (search_data->look_in_folder)) == 0) { 
 			
-				filename = g_path_get_basename (locale);
+				filename = g_path_get_basename (utf8);
 			
 				if (fnmatch (search_data->file_is_named_pattern, filename, FNM_NOESCAPE) != FNM_NOMATCH) {
 					if (search_data->show_hidden_files == TRUE) {
@@ -774,7 +779,7 @@ handle_search_command_stdout_io (GIOChannel 	*ioc,
 					}
 				}
 			}
-			g_free (locale);
+			g_free (utf8);
 			g_free (filename);
 			
 			gtk_tree_view_get_visible_rect (GTK_TREE_VIEW(interface.tree), &prior_rect);
@@ -857,7 +862,7 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 	
 		GString         *string;
 		GError          *error = NULL;
-		gchar           *locale = NULL;
+		gchar           *utf8 = NULL;
 		
 		string = g_string_new (NULL);
 		
@@ -895,8 +900,8 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 			   	    (strstr (string->str, "No such file or directory") == NULL) &&
 			   	    (strncmp (string->str, "grep: ", 6) != 0) &&
 			 	    (strcmp (string->str, "find: ") != 0)) { 
-					locale = g_locale_to_utf8 (string->str, -1, NULL, NULL, NULL);
-					error_msgs = g_string_append (error_msgs, locale); 
+					utf8 = g_locale_to_utf8 (string->str, -1, NULL, NULL, NULL);
+					error_msgs = g_string_append (error_msgs, utf8); 
 					truncate_error_msgs = limit_string_to_x_lines (error_msgs, 20);
 				}
 			}
@@ -904,7 +909,7 @@ handle_search_command_stderr_io (GIOChannel 	*ioc,
 		} while (g_io_channel_get_buffer_condition (ioc) == G_IO_IN);
 		
 		g_string_free (string, TRUE);
-		g_free (locale);
+		g_free (utf8);
 	}
 	
 	if (condition != G_IO_IN) { 
@@ -1045,7 +1050,7 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 	switch(templates[opt->constraint_id].type) {
 	case SEARCH_CONSTRAINT_BOOL:
 		{
-			gchar *desc = g_strconcat (_(templates[opt->constraint_id].desc), ".", NULL);
+			gchar *desc = g_strconcat (LEFT_LABEL_SPACING, _(templates[opt->constraint_id].desc), ".", NULL);
 			label = gtk_label_new (desc);
 			g_free (desc);
 			gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
@@ -1055,7 +1060,7 @@ create_constraint_box (SearchConstraint *opt, gchar *value)
 	case SEARCH_CONSTRAINT_NUMBER:
 	case SEARCH_CONSTRAINT_TIME:
 		{
-			gchar *desc = g_strconcat (_(templates[opt->constraint_id].desc), ":", NULL);
+			gchar *desc = g_strconcat (LEFT_LABEL_SPACING, _(templates[opt->constraint_id].desc), ":", NULL);
 			label = gtk_label_new (desc);
 			g_free (desc);
 		}
@@ -1155,7 +1160,7 @@ create_additional_constraint_section (void)
 	GtkWidget *vbox1; 
 	GtkWidget *vbox2;
 	GtkWidget *label;
-	GtkWidget *button;
+	gchar *desc;
 
 	vbox1 = gtk_vbox_new (FALSE, 0);
 	gtk_container_set_border_width (GTK_CONTAINER(vbox1), 0);
@@ -1166,7 +1171,10 @@ create_additional_constraint_section (void)
 	
 	gtk_box_pack_end (GTK_BOX(vbox2), hbox, FALSE, FALSE, 0);
 	
-	label = gtk_label_new_with_mnemonic (_("A_vailable options:"));
+	desc = g_strconcat (LEFT_LABEL_SPACING, _("A_vailable options:"), NULL);
+	label = gtk_label_new_with_mnemonic (desc);
+	g_free (desc);
+
 	gtk_box_pack_start (GTK_BOX(hbox), label, FALSE, FALSE, GNOME_PAD_SMALL);
 	
 	interface.constraint_menu = gtk_option_menu_new ();
@@ -1181,15 +1189,14 @@ create_additional_constraint_section (void)
 		add_atk_relation (interface.constraint_menu, GTK_WIDGET(label), ATK_RELATION_LABELLED_BY);
 	}
 
-	button = gtk_button_new_from_stock (GTK_STOCK_ADD);
+	interface.add_button = gtk_button_new_from_stock (GTK_STOCK_ADD);
 	interface.constraint_size_group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (interface.constraint_size_group, button);
-	gtk_size_group_add_widget (interface.constraint_size_group, gtk_button_new_from_stock (GTK_STOCK_REMOVE));
+	gtk_size_group_add_widget (interface.constraint_size_group, interface.add_button);
 	
-	g_signal_connect (G_OBJECT(button),"clicked",
+	g_signal_connect (G_OBJECT(interface.add_button),"clicked",
 			  G_CALLBACK(add_constraint_cb),NULL);
 	
-	gtk_box_pack_end (GTK_BOX(hbox), button, FALSE, FALSE, 0); 
+	gtk_box_pack_end (GTK_BOX(hbox), interface.add_button, FALSE, FALSE, 0); 
 		
 	gtk_box_pack_start (GTK_BOX(vbox1), interface.constraint, TRUE, TRUE, GNOME_PAD_SMALL);
 	
@@ -1218,7 +1225,7 @@ create_search_results_section (void)
 	gtk_widget_set_sensitive (GTK_WIDGET(interface.results), FALSE); 
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW(interface.results), GTK_SHADOW_IN);	
 	gtk_container_set_border_width (GTK_CONTAINER(interface.results), 0);
-	gtk_widget_set_usize (interface.results, 530, 200); 
+	gtk_widget_set_size_request (interface.results, 530, 200); 
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW(interface.results),
                                         GTK_POLICY_AUTOMATIC,
                                         GTK_POLICY_AUTOMATIC);
@@ -1294,9 +1301,7 @@ create_search_results_section (void)
         gtk_tree_view_column_pack_start (column, renderer, TRUE);
         gtk_tree_view_column_set_attributes (column, renderer,
                                              "text", COLUMN_NAME,
-					     NULL);
-					     
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
+					     NULL);				     
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 	gtk_tree_view_column_set_resizable (column, TRUE);				     
 	gtk_tree_view_column_set_sort_column_id (column, COLUMN_NAME); 
@@ -1307,7 +1312,6 @@ create_search_results_section (void)
 	column = gtk_tree_view_column_new_with_attributes (_("Folder"), renderer,
 							   "text", COLUMN_PATH,
 							   NULL);
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, COLUMN_PATH); 
@@ -1318,8 +1322,7 @@ create_search_results_section (void)
 	g_object_set( renderer, "xalign", 1.0, NULL);
 	column = gtk_tree_view_column_new_with_attributes (_("Size"), renderer,
 							   "text", COLUMN_READABLE_SIZE,
-							   NULL);						   
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
+							   NULL);
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, COLUMN_SIZE);
@@ -1330,7 +1333,6 @@ create_search_results_section (void)
 	column = gtk_tree_view_column_new_with_attributes (_("Type"), renderer,
 							   "text", COLUMN_TYPE,
 							   NULL);
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, COLUMN_TYPE);
@@ -1341,7 +1343,6 @@ create_search_results_section (void)
 	column = gtk_tree_view_column_new_with_attributes (_("Date Modified"), renderer,
 							   "text", COLUMN_READABLE_DATE,
 							   NULL);
-	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_FIXED);
 	gtk_tree_view_column_set_sizing (column, GTK_TREE_VIEW_COLUMN_AUTOSIZE);
 	gtk_tree_view_column_set_resizable (column, TRUE);
 	gtk_tree_view_column_set_sort_column_id (column, COLUMN_DATE);
@@ -1359,7 +1360,6 @@ create_main_window (void)
 	GtkWidget 	*entry;
 	GtkWidget 	*folder_entry;
 	GtkWidget 	*button;
-	GtkWidget 	*hsep;
 	GtkWidget 	*table;
 	GtkWidget 	*results;
 	GtkWidget 	*window;
@@ -1371,7 +1371,7 @@ create_main_window (void)
 	hbox = gtk_hbox_new (FALSE, GNOME_PAD_SMALL);
 	gtk_box_pack_start (GTK_BOX(window), hbox, FALSE, FALSE, GNOME_PAD_SMALL);
 	
-	image = gtk_image_new_from_file (GNOME_ICONDIR"/gnome-searchtool.png");
+	image = gtk_image_new_from_stock (GNOME_SEARCH_TOOL_STOCK, gsearchtool_icon_size);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, GNOME_PAD_SMALL);
 	
 	table = gtk_table_new (2, 2, FALSE);
@@ -1451,9 +1451,6 @@ create_main_window (void)
 	results = create_search_results_section ();
 	gtk_box_pack_start (GTK_BOX(window), results, TRUE, TRUE, GNOME_PAD_SMALL);
 	
-	hsep = gtk_hseparator_new ();
-	gtk_box_pack_start (GTK_BOX(window),hsep,FALSE,FALSE,0);
-	
 	hbox = gtk_hbutton_box_new ();
 	gtk_button_box_set_layout (GTK_BUTTON_BOX(hbox), GTK_BUTTONBOX_END);
 	gtk_box_pack_start (GTK_BOX(window), hbox, FALSE, TRUE, GNOME_PAD_SMALL);
@@ -1476,6 +1473,8 @@ create_main_window (void)
 
 	g_signal_connect (G_OBJECT(interface.find_button),"clicked",
 			  G_CALLBACK(click_find_cb), NULL);
+    	g_signal_connect (G_OBJECT(interface.find_button),"size_allocate",
+			  G_CALLBACK(size_allocate_cb), NULL);
 	g_signal_connect (G_OBJECT(interface.stop_button),"clicked",
 			  G_CALLBACK(click_stop_cb), NULL);
 	gtk_box_pack_end (GTK_BOX(hbox), interface.stop_button, FALSE, FALSE, GNOME_PAD_SMALL);
@@ -1492,6 +1491,43 @@ create_main_window (void)
 	return window;
 }
 
+static void
+register_gsearchtool_icon (GtkIconFactory *factory)
+{
+	GtkIconSource	*source;
+	GtkIconSet	*icon_set;
+
+	source = gtk_icon_source_new ();
+
+	gtk_icon_source_set_filename (source, GNOME_ICONDIR"/gnome-searchtool.png");
+
+	icon_set = gtk_icon_set_new ();
+	gtk_icon_set_add_source (icon_set, source);
+
+	gtk_icon_factory_add (factory, GNOME_SEARCH_TOOL_STOCK, icon_set);
+
+	gtk_icon_set_unref (icon_set);
+
+	gtk_icon_source_free (source);	
+}
+
+static void
+gsearchtool_init_stock_icons ()
+{
+	GtkIconFactory	*factory;
+
+	gsearchtool_icon_size = gtk_icon_size_register ("panel-menu",
+							GNOME_SEARCH_TOOL_DEFAULT_ICON_SIZE,
+							GNOME_SEARCH_TOOL_DEFAULT_ICON_SIZE);
+
+	factory = gtk_icon_factory_new ();
+	gtk_icon_factory_add_default (factory);
+
+	register_gsearchtool_icon (factory);
+
+	g_object_unref (factory);
+}
+
 int
 main (int 	argc, 
       char 	*argv[])
@@ -1516,10 +1552,10 @@ main (int 	argc,
 					  GNOME_PARAM_POPT_FLAGS, 0,
 					  GNOME_PARAM_APP_DATADIR, DATADIR,  
 					  NULL);
-					  
+	gsearchtool_init_stock_icons ();				  
 	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-searchtool.png");
 
-	if (!bonobo_init (bonobo_activation_orb_get (), NULL, NULL))
+	if (!bonobo_init_full (&argc, argv, bonobo_activation_orb_get (), NULL, NULL))
 		g_error (_("Cannot initialize bonobo."));
 
 	bonobo_activate ();
